@@ -170,13 +170,13 @@ namespace Nickvision::TubeConverter::Shared::Models
         return DownloadStatus::Queued;
     }
 
-    size_t DownloadManager::startup()
+    size_t DownloadManager::startup(bool recoverDownloads)
     {
         //Load Historic Downloads
         m_logger.log(LogLevel::Info, "Loaded " + std::to_string(m_history.getHistory().size()) + " historic download(s).");
         m_historyChanged.invoke(m_history.getHistory());
         //Recover Crashed Downloads
-        if(!m_options.getRecoverCrashedDownloads())
+        if(!recoverDownloads)
         {
             m_logger.log(LogLevel::Info, "Skipping recoverable downloads.");
             m_recoveryQueue.clear();
@@ -313,7 +313,7 @@ namespace Nickvision::TubeConverter::Shared::Models
                 return UrlInfo{ obj["title"].is_string() ? obj["title"].as_string().c_str() : url, urlInfos };
             }
         }
-        return UrlInfo{ url, obj, m_options.getIncludeAutoGeneratedSubtitles(), m_options.getPreferredVideoCodec() };
+        return UrlInfo{ url, obj, m_options.getIncludeMediaIdInTitle(), m_options.getIncludeAutoGeneratedSubtitles(), m_options.getPreferredVideoCodec() };
     }
 
     std::optional<UrlInfo> DownloadManager::fetchUrlInfoFromBatchFile(const std::filesystem::path& batchFile, const std::optional<Credential>& credential) const
