@@ -17,8 +17,9 @@ namespace Nickvision::TubeConverter::Shared::Models
 {
     DownloadOptions::DownloadOptions()
         : m_fileType{ MediaFileType::MP4 },
+        m_splitChapters{ false },
         m_limitSpeed{ false },
-        m_splitChapters{ false }
+        m_exportDescription{ false }
     {
 
     }
@@ -26,8 +27,9 @@ namespace Nickvision::TubeConverter::Shared::Models
     DownloadOptions::DownloadOptions(const std::string& url)
         : m_url{ url },
         m_fileType{ MediaFileType::MP4 },
+        m_splitChapters{ false },
         m_limitSpeed{ false },
-        m_splitChapters{ false }
+        m_exportDescription{ false }
     {
 
     }
@@ -37,8 +39,9 @@ namespace Nickvision::TubeConverter::Shared::Models
         m_fileType{ json["FileType"].is_int64() ? static_cast<MediaFileType::MediaFileTypeValue>(json["FileType"].as_int64()) : MediaFileType::MP4 },
         m_saveFolder{ json["SaveFolder"].is_string() ? json["SaveFolder"].as_string().c_str() : "" },
         m_saveFilename{ json["SaveFilename"].is_string() ? json["SaveFilename"].as_string().c_str() : "" },
+        m_splitChapters{ json["SplitChapters"].is_bool() ? json["SplitChapters"].as_bool() : false },
         m_limitSpeed{ json["LimitSpeed"].is_bool() ? json["LimitSpeed"].as_bool() : false },
-        m_splitChapters{ json["SplitChapters"].is_bool() ? json["SplitChapters"].as_bool() : false }
+        m_exportDescription{ json["ExportDescription"].is_bool() ? json["ExportDescription"].as_bool() : false }
     {
         if(json["Credential"].is_object())
         {
@@ -170,6 +173,16 @@ namespace Nickvision::TubeConverter::Shared::Models
         m_subtitleLanguages = subtitleLanguages;
     }
 
+    bool DownloadOptions::getSplitChapters() const
+    {
+        return m_splitChapters;
+    }
+
+    void DownloadOptions::setSplitChapters(bool splitChapters)
+    {
+        m_splitChapters = splitChapters;
+    }
+
     bool DownloadOptions::getLimitSpeed() const
     {
         return m_limitSpeed;
@@ -184,14 +197,14 @@ namespace Nickvision::TubeConverter::Shared::Models
         m_limitSpeed = limitSpeed;
     }
 
-    bool DownloadOptions::getSplitChapters() const
+    bool DownloadOptions::getExportDescription() const
     {
-        return m_splitChapters;
+        return m_exportDescription;
     }
 
-    void DownloadOptions::setSplitChapters(bool splitChapters)
+    void DownloadOptions::setExportDescription(bool exportDescription)
     {
-        m_splitChapters = splitChapters;
+        m_exportDescription = exportDescription;
     }
 
     const std::optional<TimeFrame>& DownloadOptions::getTimeFrame() const
@@ -260,11 +273,6 @@ namespace Nickvision::TubeConverter::Shared::Models
             arguments.push_back("--downloader-args");
             arguments.push_back("aria2c:-x " + std::to_string(downloaderOptions.getAriaMaxConnectionsPerServer()) + " -k " + std::to_string(downloaderOptions.getAriaMinSplitSize()) + "M");
         }
-        else
-        {
-            arguments.push_back("--downloader");
-            arguments.push_back("native");
-        }
         if(!downloaderOptions.getProxyUrl().empty())
         {
             arguments.push_back("--proxy");
@@ -326,7 +334,7 @@ namespace Nickvision::TubeConverter::Shared::Models
             }
             arguments.push_back("--convert-thumbnails");
             arguments.push_back("jpg");
-            if(downloaderOptions.getCropAudioThumbnails())
+            if(downloaderOptions.getCropAudioThumbnails() && m_fileType.isAudio())
             {
                 arguments.push_back("--postprocessor-args");
                 arguments.push_back("ThumbnailsConvertor:-vf crop=ih:ih");
@@ -422,17 +430,16 @@ namespace Nickvision::TubeConverter::Shared::Models
             languages += "-live_chat";
             arguments.push_back("--sub-langs");
             arguments.push_back(languages);
+            arguments.push_back("--write-subs");
+            if(downloaderOptions.getIncludeAutoGeneratedSubtitles())
+            {
+                arguments.push_back("--write-auto-subs");
+            }
             if(downloaderOptions.getEmbedSubtitles() && m_fileType.supportsSubtitles())
             {
                 arguments.push_back("--embed-subs");
-            }
-            else
-            {
-                arguments.push_back("--write-subs");
-                if(downloaderOptions.getIncludeAutoGeneratedSubtitles())
-                {
-                    arguments.push_back("--write-auto-subs");
-                }
+                arguments.push_back("--compat-options");
+                arguments.push_back("no-keep-subs");
             }
             if(downloaderOptions.getPreferredSubtitleFormat() != SubtitleFormat::Any)
             {
@@ -470,19 +477,24 @@ namespace Nickvision::TubeConverter::Shared::Models
                 }
             }
         }
+        if(m_splitChapters)
+        {
+            arguments.push_back("--split-chapters");
+        }
         if(m_limitSpeed)
         {
             arguments.push_back("--limit-rate");
             arguments.push_back(std::to_string(downloaderOptions.getSpeedLimit()) + "K");
         }
-        if(m_splitChapters)
+        if(m_exportDescription)
         {
-            arguments.push_back("--split-chapters");
+            arguments.push_back("--write-description");
         }
         if(m_timeFrame.has_value())
         {
             arguments.push_back("--download-sections");
             arguments.push_back("*" + m_timeFrame->str());
+            arguments.push_back("--force-keyframes-at-cuts");
         }
         arguments.push_back("--postprocessor-args");
         arguments.push_back("-threads " + std::to_string(downloaderOptions.getPostprocessingThreads()));
@@ -532,8 +544,9 @@ namespace Nickvision::TubeConverter::Shared::Models
             subtitleLanguages.push_back(language.toJson());
         }
         json["SubtitleLanguages"] = subtitleLanguages;
-        json["LimitSpeed"] = m_limitSpeed;
         json["SplitChapters"] = m_splitChapters;
+        json["LimitSpeed"] = m_limitSpeed;
+        json["ExportDescription"] = m_exportDescription;
         if(m_timeFrame)
         {
             json["TimeFrame"] = m_timeFrame->toJson();
