@@ -31,9 +31,24 @@ namespace Nickvision::TubeConverter::GNOME
     private:
         /**
          * @brief Handles starting the application.
-         * @param app The GtkApplication for the running app 
+         * @param app The GtkApplication for the running app
+         */
+        void onStartup(GtkApplication* app);
+        /**
+         * @brief Handles activating the application.
+         * @param app The GtkApplication for the running app
          */
         void onActivate(GtkApplication* app);
+        /**
+         * @brief Handles opening files.
+         * @param app The GtkApplication for the running app
+         * @param files The files to open
+         * @param n The number of files to open
+         * @param hint The hint for opening the files 
+         */
+        void onOpen(GtkApplication* app, void* files, int n, const char* hint);
+        int m_argc;
+        char** m_argv;
         std::shared_ptr<Shared::Controllers::MainWindowController> m_controller;
         AdwApplication* m_adw;
         std::shared_ptr<Views::MainWindow> m_mainWindow;
