@@ -16,8 +16,10 @@ namespace Nickvision::TubeConverter::QT::Helpers::QTHelpers
     /**
      * @brief Sets the items of a QComboBox from a vector of strings.
      * @param comboBox The QComboBox to set the items of
+     * @param items The items to set
+     * @param selected An option string that should be selected
      */
-    void setComboBoxItems(QComboBox* comboBox, const std::vector<std::string>& items);
+    void setComboBoxItems(QComboBox* comboBox, const std::vector<std::string>& items, const std::string& selected = "");
 }
 
 #endif //QTHELPERS_H
\ No newline at end of file
