@@ -18,13 +18,19 @@ namespace Nickvision::TubeConverter::QT::Helpers
         QMetaObject::invokeMethod(timer, "start", Qt::ConnectionType::AutoConnection, Q_ARG(int, 0));
     }
 
-    void QTHelpers::setComboBoxItems(QComboBox* comboBox, const std::vector<std::string>& items)
+    void QTHelpers::setComboBoxItems(QComboBox* comboBox, const std::vector<std::string>& items, const std::string& selected)
     {
+        size_t selectedIndex{ 0 };
         comboBox->clear();
-        for(const std::string& item : items)
+        for(size_t i = 0; i < items.size(); i++)
         {
+            const std::string& item{ items[i] };
             comboBox->addItem(QString::fromStdString(item));
+            if(item == selected)
+            {
+                selectedIndex = i;
+            }
         }
-        comboBox->setCurrentIndex(0);
+        comboBox->setCurrentIndex(selectedIndex);
     }
 }
\ No newline at end of file
